<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RestrictHorizontal</name>
    <message>
        <location filename="../RestrictHorizontalInit.js" line="+2"/>
        <source>Restrict &amp;Horizontally</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ograniczaj &amp;poziomo</translatorcomment>
        <translation>Ograniczanie p&amp;oziomo</translation>
    </message>
</context>
</TS>
